Numerical integration (quadrature)
----------------------------------

Standard quadrature (``quad``)
..............................

.. autofunction:: mpmath.quad

Quadrature with subdivision (``quadsubdiv``)
............................................

.. autofunction:: mpmath.quadsubdiv

Oscillatory quadrature (``quadosc``)
....................................

.. autofunction:: mpmath.quadosc

Quadrature rules
................

.. autoclass:: mpmath.calculus.quadrature.QuadratureRule
   :members:

Tanh-sinh rule
~~~~~~~~~~~~~~

.. autoclass:: mpmath.calculus.quadrature.TanhSinh
   :members:


Gauss-Legendre rule
~~~~~~~~~~~~~~~~~~~

.. autoclass:: mpmath.calculus.quadrature.GaussLegendre
   :members:
